import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.osidb_api_v1_status_retrieve_response_200_osidb_data import (
    OsidbApiV1StatusRetrieveResponse200OsidbData,
)
from ..models.osidb_api_v1_status_retrieve_response_200_osidb_service import (
    OsidbApiV1StatusRetrieveResponse200OsidbService,
)
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="OsidbApiV1StatusRetrieveResponse200")


@attr.s(auto_attribs=True)
class OsidbApiV1StatusRetrieveResponse200(OSIDBModel):
    """ """

    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    osidb_data: Union[Unset, OsidbApiV1StatusRetrieveResponse200OsidbData] = UNSET
    osidb_service: Union[Unset, OsidbApiV1StatusRetrieveResponse200OsidbService] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env
        osidb_data: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.osidb_data, Unset):
            osidb_data = self.osidb_data.to_dict()

        osidb_service: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.osidb_service, Unset):
            osidb_service = self.osidb_service.to_dict()

        revision = self.revision
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if dt is not UNSET:
            field_dict["dt"] = dt
        if env is not UNSET:
            field_dict["env"] = env
        if osidb_data is not UNSET:
            field_dict["osidb_data"] = osidb_data
        if osidb_service is not UNSET:
            field_dict["osidb_service"] = osidb_service
        if revision is not UNSET:
            field_dict["revision"] = revision
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        _osidb_data = d.pop("osidb_data", UNSET)
        osidb_data: Union[Unset, OsidbApiV1StatusRetrieveResponse200OsidbData]
        if isinstance(_osidb_data, Unset):
            osidb_data = UNSET
        else:
            osidb_data = OsidbApiV1StatusRetrieveResponse200OsidbData.from_dict(
                _osidb_data
            )

        _osidb_service = d.pop("osidb_service", UNSET)
        osidb_service: Union[Unset, OsidbApiV1StatusRetrieveResponse200OsidbService]
        if isinstance(_osidb_service, Unset):
            osidb_service = UNSET
        else:
            osidb_service = OsidbApiV1StatusRetrieveResponse200OsidbService.from_dict(
                _osidb_service
            )

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_status_retrieve_response_200 = cls(
            dt=dt,
            env=env,
            osidb_data=osidb_data,
            osidb_service=osidb_service,
            revision=revision,
            version=version,
        )

        osidb_api_v1_status_retrieve_response_200.additional_properties = d
        return osidb_api_v1_status_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "dt": datetime.datetime,
            "env": str,
            "osidb_data": OsidbApiV1StatusRetrieveResponse200OsidbData,
            "osidb_service": OsidbApiV1StatusRetrieveResponse200OsidbService,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class FlawMetaType(str, Enum):
    ERRATA = "ERRATA"
    REFERENCE = "REFERENCE"
    ACKNOWLEDGMENT = "ACKNOWLEDGMENT"
    EXPLOIT = "EXPLOIT"
    MAJOR_INCIDENT = "MAJOR_INCIDENT"
    MAJOR_INCIDENT_LITE = "MAJOR_INCIDENT_LITE"
    REQUIRES_SUMMARY = "REQUIRES_SUMMARY"
    NIST_CVSS_VALIDATION = "NIST_CVSS_VALIDATION"
    NEED_INFO = "NEED_INFO"
    CHECKLIST = "CHECKLIST"
    NVD_CVSS = "NVD_CVSS"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.jira_issue_fields import JiraIssueFields
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="JiraIssue")


@attr.s(auto_attribs=True)
class JiraIssue(OSIDBModel):
    """ """

    id: int
    key: str
    name: str
    fields: JiraIssueFields
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        key = self.key
        name = self.name
        fields: Dict[str, Any] = UNSET
        if not isinstance(self.fields, Unset):
            fields = self.fields.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if id is not UNSET:
            field_dict["id"] = id
        if key is not UNSET:
            field_dict["key"] = key
        if name is not UNSET:
            field_dict["name"] = name
        if fields is not UNSET:
            field_dict["fields"] = fields

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        key = d.pop("key", UNSET)

        name = d.pop("name", UNSET)

        _fields = d.pop("fields", UNSET)
        fields: JiraIssueFields
        if isinstance(_fields, Unset):
            fields = UNSET
        else:
            fields = JiraIssueFields.from_dict(_fields)

        jira_issue = cls(
            id=id,
            key=key,
            name=name,
            fields=fields,
        )

        jira_issue.additional_properties = d
        return jira_issue

    @staticmethod
    def get_fields():
        return {
            "id": int,
            "key": str,
            "name": str,
            "fields": JiraIssueFields,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.tracker_type import TrackerType
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="TrackerReportData")


@attr.s(auto_attribs=True)
class TrackerReportData(OSIDBModel):
    """ """

    type: TrackerType
    external_system_id: str
    status: str
    resolution: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type: str = UNSET
        if not isinstance(self.type, Unset):

            type = TrackerType(self.type).value

        external_system_id = self.external_system_id
        status = self.status
        resolution = self.resolution

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if type is not UNSET:
            field_dict["type"] = type
        if external_system_id is not UNSET:
            field_dict["external_system_id"] = external_system_id
        if status is not UNSET:
            field_dict["status"] = status
        if resolution is not UNSET:
            field_dict["resolution"] = resolution

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _type = d.pop("type", UNSET)
        type: TrackerType
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = TrackerType(_type)

        external_system_id = d.pop("external_system_id", UNSET)

        status = d.pop("status", UNSET)

        resolution = d.pop("resolution", UNSET)

        tracker_report_data = cls(
            type=type,
            external_system_id=external_system_id,
            status=status,
            resolution=resolution,
        )

        tracker_report_data.additional_properties = d
        return tracker_report_data

    @staticmethod
    def get_fields():
        return {
            "type": TrackerType,
            "external_system_id": str,
            "status": str,
            "resolution": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="ExploitsApiV1StatusRetrieveResponse200")


@attr.s(auto_attribs=True)
class ExploitsApiV1StatusRetrieveResponse200(OSIDBModel):
    """ """

    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    exploits_count: Union[Unset, int] = UNSET
    exploits_count_relevant: Union[Unset, int] = UNSET
    last_exploit: Union[Unset, int] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env
        exploits_count = self.exploits_count
        exploits_count_relevant = self.exploits_count_relevant
        last_exploit = self.last_exploit
        revision = self.revision
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if dt is not UNSET:
            field_dict["dt"] = dt
        if env is not UNSET:
            field_dict["env"] = env
        if exploits_count is not UNSET:
            field_dict["exploits_count"] = exploits_count
        if exploits_count_relevant is not UNSET:
            field_dict["exploits_count_relevant"] = exploits_count_relevant
        if last_exploit is not UNSET:
            field_dict["last_exploit"] = last_exploit
        if revision is not UNSET:
            field_dict["revision"] = revision
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        exploits_count = d.pop("exploits_count", UNSET)

        exploits_count_relevant = d.pop("exploits_count_relevant", UNSET)

        last_exploit = d.pop("last_exploit", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        exploits_api_v1_status_retrieve_response_200 = cls(
            dt=dt,
            env=env,
            exploits_count=exploits_count,
            exploits_count_relevant=exploits_count_relevant,
            last_exploit=last_exploit,
            revision=revision,
            version=version,
        )

        exploits_api_v1_status_retrieve_response_200.additional_properties = d
        return exploits_api_v1_status_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "dt": datetime.datetime,
            "env": str,
            "exploits_count": int,
            "exploits_count_relevant": int,
            "last_exploit": int,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional

import requests

from ...client import AuthenticatedClient
from ...models.taskman_api_v1_task_flaw_retrieve_response_200 import (
    TaskmanApiV1TaskFlawRetrieveResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}


def _get_kwargs(
    flaw_uuid: str,
    *,
    client: AuthenticatedClient,
    jira_authentication: str,
) -> Dict[str, Any]:
    url = "{}/taskman/api/v1/task/flaw/{flaw_uuid}".format(
        client.base_url,
        flaw_uuid=flaw_uuid,
    )

    headers: Dict[str, Any] = client.get_headers()

    headers["jira-authentication"] = jira_authentication

    return {
        "url": url,
        "headers": headers,
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[TaskmanApiV1TaskFlawRetrieveResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: TaskmanApiV1TaskFlawRetrieveResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = TaskmanApiV1TaskFlawRetrieveResponse200.from_dict(
                _response_200
            )

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[TaskmanApiV1TaskFlawRetrieveResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    flaw_uuid: str,
    *,
    client: AuthenticatedClient,
    jira_authentication: str,
) -> Response[TaskmanApiV1TaskFlawRetrieveResponse200]:
    kwargs = _get_kwargs(
        flaw_uuid=flaw_uuid,
        client=client,
        jira_authentication=jira_authentication,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    flaw_uuid: str,
    *,
    client: AuthenticatedClient,
    jira_authentication: str,
) -> Optional[TaskmanApiV1TaskFlawRetrieveResponse200]:
    """Get a task from Jira given a Flaw uuid"""

    return sync_detailed(
        flaw_uuid=flaw_uuid,
        client=client,
        jira_authentication=jira_authentication,
    ).parsed



from typing import Any, Dict, Optional

import requests

from ...client import AuthenticatedClient
from ...models.flaw import Flaw
from ...models.osidb_api_v1_flaws_update_response_200 import (
    OsidbApiV1FlawsUpdateResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}
REQUEST_BODY_TYPE = Flaw


def _get_kwargs(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
) -> Dict[str, Any]:
    url = "{}/osidb/api/v1/flaws/{id}".format(
        client.base_url,
        id=id,
    )

    headers: Dict[str, Any] = client.get_headers()

    json_json_body: Dict[str, Any] = UNSET
    if not isinstance(json_body, Unset):
        json_body.to_dict()

    multipart_multipart_data: Dict[str, Any] = UNSET
    if not isinstance(multipart_data, Unset):
        multipart_data.to_multipart()

    return {
        "url": url,
        "headers": headers,
        "data": form_data.to_dict(),
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[OsidbApiV1FlawsUpdateResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1FlawsUpdateResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1FlawsUpdateResponse200.from_dict(_response_200)

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[OsidbApiV1FlawsUpdateResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
) -> Response[OsidbApiV1FlawsUpdateResponse200]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        form_data=form_data,
        multipart_data=multipart_data,
        json_body=json_body,
    )

    response = requests.put(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
) -> Optional[OsidbApiV1FlawsUpdateResponse200]:
    """ """

    return sync_detailed(
        id=id,
        client=client,
        form_data=form_data,
        multipart_data=multipart_data,
        json_body=json_body,
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.cv_ev_5_versions import CVEv5Versions
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="CVEv5PackageVersions")


@attr.s(auto_attribs=True)
class CVEv5PackageVersions(OSIDBModel):
    """CVEv5 package versions serializer"""

    package: str
    versions: List[CVEv5Versions]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        package = self.package
        versions: List[Dict[str, Any]] = UNSET
        if not isinstance(self.versions, Unset):
            versions = []
            for versions_item_data in self.versions:
                versions_item: Dict[str, Any] = UNSET
                if not isinstance(versions_item_data, Unset):
                    versions_item = versions_item_data.to_dict()

                versions.append(versions_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if package is not UNSET:
            field_dict["package"] = package
        if versions is not UNSET:
            field_dict["versions"] = versions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        package = d.pop("package", UNSET)

        versions = []
        _versions = d.pop("versions", UNSET)
        if _versions is UNSET:
            versions = UNSET
        else:
            for versions_item_data in _versions or []:
                _versions_item = versions_item_data
                versions_item: CVEv5Versions
                if isinstance(_versions_item, Unset):
                    versions_item = UNSET
                else:
                    versions_item = CVEv5Versions.from_dict(_versions_item)

                versions.append(versions_item)

        cv_ev_5_package_versions = cls(
            package=package,
            versions=versions,
        )

        cv_ev_5_package_versions.additional_properties = d
        return cv_ev_5_package_versions

    @staticmethod
    def get_fields():
        return {
            "package": str,
            "versions": List[CVEv5Versions],
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.affect import Affect
from ..models.blank_enum import BlankEnum
from ..models.comment import Comment
from ..models.cv_ev_5_package_versions import CVEv5PackageVersions
from ..models.flaw_classification import FlawClassification
from ..models.flaw_meta_attr import FlawMetaAttr
from ..models.flaw_reference import FlawReference
from ..models.flaw_type import FlawType
from ..models.impact_enum import ImpactEnum
from ..models.meta import Meta
from ..models.source_666_enum import Source666Enum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="OsidbApiV1FlawsRetrieveResponse200")


@attr.s(auto_attribs=True)
class OsidbApiV1FlawsRetrieveResponse200(OSIDBModel):
    """ """

    uuid: str
    state: str
    resolution: str
    title: str
    trackers: List[str]
    description: str
    affects: List[Affect]
    meta: List[Meta]
    comments: List[Comment]
    meta_attr: FlawMetaAttr
    package_versions: List[CVEv5PackageVersions]
    references: List[FlawReference]
    embargoed: bool
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    classification: FlawClassification
    type: Union[Unset, FlawType] = UNSET
    cve_id: Union[Unset, None, str] = UNSET
    impact: Union[BlankEnum, ImpactEnum, Unset] = UNSET
    component: Union[Unset, str] = UNSET
    summary: Union[Unset, str] = UNSET
    statement: Union[Unset, str] = UNSET
    cwe_id: Union[Unset, str] = UNSET
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET
    source: Union[BlankEnum, Source666Enum, Unset] = UNSET
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET
    mitigation: Union[Unset, str] = UNSET
    cvss2: Union[Unset, str] = UNSET
    cvss2_score: Union[Unset, None, float] = UNSET
    nvd_cvss2: Union[Unset, str] = UNSET
    cvss3: Union[Unset, str] = UNSET
    cvss3_score: Union[Unset, None, float] = UNSET
    nvd_cvss3: Union[Unset, str] = UNSET
    is_major_incident: Union[Unset, bool] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        state = self.state
        resolution = self.resolution
        title = self.title
        trackers: List[str] = UNSET
        if not isinstance(self.trackers, Unset):
            trackers = self.trackers

        description = self.description
        affects: List[Dict[str, Any]] = UNSET
        if not isinstance(self.affects, Unset):
            affects = []
            for affects_item_data in self.affects:
                affects_item: Dict[str, Any] = UNSET
                if not isinstance(affects_item_data, Unset):
                    affects_item = affects_item_data.to_dict()

                affects.append(affects_item)

        meta: List[Dict[str, Any]] = UNSET
        if not isinstance(self.meta, Unset):
            meta = []
            for meta_item_data in self.meta:
                meta_item: Dict[str, Any] = UNSET
                if not isinstance(meta_item_data, Unset):
                    meta_item = meta_item_data.to_dict()

                meta.append(meta_item)

        comments: List[Dict[str, Any]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item: Dict[str, Any] = UNSET
                if not isinstance(comments_item_data, Unset):
                    comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        meta_attr: Dict[str, Any] = UNSET
        if not isinstance(self.meta_attr, Unset):
            meta_attr = self.meta_attr.to_dict()

        package_versions: List[Dict[str, Any]] = UNSET
        if not isinstance(self.package_versions, Unset):
            package_versions = []
            for package_versions_item_data in self.package_versions:
                package_versions_item: Dict[str, Any] = UNSET
                if not isinstance(package_versions_item_data, Unset):
                    package_versions_item = package_versions_item_data.to_dict()

                package_versions.append(package_versions_item)

        references: List[Dict[str, Any]] = UNSET
        if not isinstance(self.references, Unset):
            references = []
            for references_item_data in self.references:
                references_item: Dict[str, Any] = UNSET
                if not isinstance(references_item_data, Unset):
                    references_item = references_item_data.to_dict()

                references.append(references_item)

        embargoed = self.embargoed
        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        classification: Dict[str, Any] = UNSET
        if not isinstance(self.classification, Unset):
            classification = self.classification.to_dict()

        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):

            type = FlawType(self.type).value

        cve_id = self.cve_id
        impact: Union[Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = ImpactEnum(self.impact).value

        else:
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = BlankEnum(self.impact).value

        component = self.component
        summary = self.summary
        statement = self.statement
        cwe_id = self.cwe_id
        unembargo_dt: Union[Unset, None, str] = UNSET
        if not isinstance(self.unembargo_dt, Unset):
            unembargo_dt = self.unembargo_dt.isoformat() if self.unembargo_dt else None

        source: Union[Unset, str]
        if isinstance(self.source, Unset):
            source = UNSET
        elif isinstance(self.source, Source666Enum):
            source = UNSET
            if not isinstance(self.source, Unset):

                source = Source666Enum(self.source).value

        else:
            source = UNSET
            if not isinstance(self.source, Unset):

                source = BlankEnum(self.source).value

        reported_dt: Union[Unset, None, str] = UNSET
        if not isinstance(self.reported_dt, Unset):
            reported_dt = self.reported_dt.isoformat() if self.reported_dt else None

        mitigation = self.mitigation
        cvss2 = self.cvss2
        cvss2_score = self.cvss2_score
        nvd_cvss2 = self.nvd_cvss2
        cvss3 = self.cvss3
        cvss3_score = self.cvss3_score
        nvd_cvss3 = self.nvd_cvss3
        is_major_incident = self.is_major_incident
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env
        revision = self.revision
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if state is not UNSET:
            field_dict["state"] = state
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if title is not UNSET:
            field_dict["title"] = title
        if trackers is not UNSET:
            field_dict["trackers"] = trackers
        if description is not UNSET:
            field_dict["description"] = description
        if affects is not UNSET:
            field_dict["affects"] = affects
        if meta is not UNSET:
            field_dict["meta"] = meta
        if comments is not UNSET:
            field_dict["comments"] = comments
        if meta_attr is not UNSET:
            field_dict["meta_attr"] = meta_attr
        if package_versions is not UNSET:
            field_dict["package_versions"] = package_versions
        if references is not UNSET:
            field_dict["references"] = references
        if embargoed is not UNSET:
            field_dict["embargoed"] = embargoed
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if updated_dt is not UNSET:
            field_dict["updated_dt"] = updated_dt
        if classification is not UNSET:
            field_dict["classification"] = classification
        if type is not UNSET:
            field_dict["type"] = type
        if cve_id is not UNSET:
            field_dict["cve_id"] = cve_id
        if impact is not UNSET:
            field_dict["impact"] = impact
        if component is not UNSET:
            field_dict["component"] = component
        if summary is not UNSET:
            field_dict["summary"] = summary
        if statement is not UNSET:
            field_dict["statement"] = statement
        if cwe_id is not UNSET:
            field_dict["cwe_id"] = cwe_id
        if unembargo_dt is not UNSET:
            field_dict["unembargo_dt"] = unembargo_dt
        if source is not UNSET:
            field_dict["source"] = source
        if reported_dt is not UNSET:
            field_dict["reported_dt"] = reported_dt
        if mitigation is not UNSET:
            field_dict["mitigation"] = mitigation
        if cvss2 is not UNSET:
            field_dict["cvss2"] = cvss2
        if cvss2_score is not UNSET:
            field_dict["cvss2_score"] = cvss2_score
        if nvd_cvss2 is not UNSET:
            field_dict["nvd_cvss2"] = nvd_cvss2
        if cvss3 is not UNSET:
            field_dict["cvss3"] = cvss3
        if cvss3_score is not UNSET:
            field_dict["cvss3_score"] = cvss3_score
        if nvd_cvss3 is not UNSET:
            field_dict["nvd_cvss3"] = nvd_cvss3
        if is_major_incident is not UNSET:
            field_dict["is_major_incident"] = is_major_incident
        if dt is not UNSET:
            field_dict["dt"] = dt
        if env is not UNSET:
            field_dict["env"] = env
        if revision is not UNSET:
            field_dict["revision"] = revision
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        state = d.pop("state", UNSET)

        resolution = d.pop("resolution", UNSET)

        title = d.pop("title", UNSET)

        trackers = cast(List[str], d.pop("trackers", UNSET))

        description = d.pop("description", UNSET)

        affects = []
        _affects = d.pop("affects", UNSET)
        if _affects is UNSET:
            affects = UNSET
        else:
            for affects_item_data in _affects or []:
                _affects_item = affects_item_data
                affects_item: Affect
                if isinstance(_affects_item, Unset):
                    affects_item = UNSET
                else:
                    affects_item = Affect.from_dict(_affects_item)

                affects.append(affects_item)

        meta = []
        _meta = d.pop("meta", UNSET)
        if _meta is UNSET:
            meta = UNSET
        else:
            for meta_item_data in _meta or []:
                _meta_item = meta_item_data
                meta_item: Meta
                if isinstance(_meta_item, Unset):
                    meta_item = UNSET
                else:
                    meta_item = Meta.from_dict(_meta_item)

                meta.append(meta_item)

        comments = []
        _comments = d.pop("comments", UNSET)
        if _comments is UNSET:
            comments = UNSET
        else:
            for comments_item_data in _comments or []:
                _comments_item = comments_item_data
                comments_item: Comment
                if isinstance(_comments_item, Unset):
                    comments_item = UNSET
                else:
                    comments_item = Comment.from_dict(_comments_item)

                comments.append(comments_item)

        _meta_attr = d.pop("meta_attr", UNSET)
        meta_attr: FlawMetaAttr
        if isinstance(_meta_attr, Unset):
            meta_attr = UNSET
        else:
            meta_attr = FlawMetaAttr.from_dict(_meta_attr)

        package_versions = []
        _package_versions = d.pop("package_versions", UNSET)
        if _package_versions is UNSET:
            package_versions = UNSET
        else:
            for package_versions_item_data in _package_versions or []:
                _package_versions_item = package_versions_item_data
                package_versions_item: CVEv5PackageVersions
                if isinstance(_package_versions_item, Unset):
                    package_versions_item = UNSET
                else:
                    package_versions_item = CVEv5PackageVersions.from_dict(
                        _package_versions_item
                    )

                package_versions.append(package_versions_item)

        references = []
        _references = d.pop("references", UNSET)
        if _references is UNSET:
            references = UNSET
        else:
            for references_item_data in _references or []:
                _references_item = references_item_data
                references_item: FlawReference
                if isinstance(_references_item, Unset):
                    references_item = UNSET
                else:
                    references_item = FlawReference.from_dict(_references_item)

                references.append(references_item)

        embargoed = d.pop("embargoed", UNSET)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        _classification = d.pop("classification", UNSET)
        classification: FlawClassification
        if isinstance(_classification, Unset):
            classification = UNSET
        else:
            classification = FlawClassification.from_dict(_classification)

        _type = d.pop("type", UNSET)
        type: Union[Unset, FlawType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = FlawType(_type)

        cve_id = d.pop("cve_id", UNSET)

        def _parse_impact(data: object) -> Union[BlankEnum, ImpactEnum, Unset]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_0 = data
                impact_type_0: Union[Unset, ImpactEnum]
                if isinstance(_impact_type_0, Unset):
                    impact_type_0 = UNSET
                else:
                    impact_type_0 = ImpactEnum(_impact_type_0)

                return impact_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _impact_type_1 = data
            impact_type_1: Union[Unset, BlankEnum]
            if isinstance(_impact_type_1, Unset):
                impact_type_1 = UNSET
            else:
                impact_type_1 = BlankEnum(_impact_type_1)

            return impact_type_1

        impact = _parse_impact(d.pop("impact", UNSET))

        component = d.pop("component", UNSET)

        summary = d.pop("summary", UNSET)

        statement = d.pop("statement", UNSET)

        cwe_id = d.pop("cwe_id", UNSET)

        _unembargo_dt = d.pop("unembargo_dt", UNSET)
        unembargo_dt: Union[Unset, None, datetime.datetime]
        if _unembargo_dt is None:
            unembargo_dt = None
        elif isinstance(_unembargo_dt, Unset):
            unembargo_dt = UNSET
        else:
            unembargo_dt = isoparse(_unembargo_dt)

        def _parse_source(data: object) -> Union[BlankEnum, Source666Enum, Unset]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _source_type_0 = data
                source_type_0: Union[Unset, Source666Enum]
                if isinstance(_source_type_0, Unset):
                    source_type_0 = UNSET
                else:
                    source_type_0 = Source666Enum(_source_type_0)

                return source_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _source_type_1 = data
            source_type_1: Union[Unset, BlankEnum]
            if isinstance(_source_type_1, Unset):
                source_type_1 = UNSET
            else:
                source_type_1 = BlankEnum(_source_type_1)

            return source_type_1

        source = _parse_source(d.pop("source", UNSET))

        _reported_dt = d.pop("reported_dt", UNSET)
        reported_dt: Union[Unset, None, datetime.datetime]
        if _reported_dt is None:
            reported_dt = None
        elif isinstance(_reported_dt, Unset):
            reported_dt = UNSET
        else:
            reported_dt = isoparse(_reported_dt)

        mitigation = d.pop("mitigation", UNSET)

        cvss2 = d.pop("cvss2", UNSET)

        cvss2_score = d.pop("cvss2_score", UNSET)

        nvd_cvss2 = d.pop("nvd_cvss2", UNSET)

        cvss3 = d.pop("cvss3", UNSET)

        cvss3_score = d.pop("cvss3_score", UNSET)

        nvd_cvss3 = d.pop("nvd_cvss3", UNSET)

        is_major_incident = d.pop("is_major_incident", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_flaws_retrieve_response_200 = cls(
            uuid=uuid,
            state=state,
            resolution=resolution,
            title=title,
            trackers=trackers,
            description=description,
            affects=affects,
            meta=meta,
            comments=comments,
            meta_attr=meta_attr,
            package_versions=package_versions,
            references=references,
            embargoed=embargoed,
            created_dt=created_dt,
            updated_dt=updated_dt,
            classification=classification,
            type=type,
            cve_id=cve_id,
            impact=impact,
            component=component,
            summary=summary,
            statement=statement,
            cwe_id=cwe_id,
            unembargo_dt=unembargo_dt,
            source=source,
            reported_dt=reported_dt,
            mitigation=mitigation,
            cvss2=cvss2,
            cvss2_score=cvss2_score,
            nvd_cvss2=nvd_cvss2,
            cvss3=cvss3,
            cvss3_score=cvss3_score,
            nvd_cvss3=nvd_cvss3,
            is_major_incident=is_major_incident,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v1_flaws_retrieve_response_200.additional_properties = d
        return osidb_api_v1_flaws_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "uuid": str,
            "state": str,
            "resolution": str,
            "title": str,
            "trackers": List[str],
            "description": str,
            "affects": List[Affect],
            "meta": List[Meta],
            "comments": List[Comment],
            "meta_attr": FlawMetaAttr,
            "package_versions": List[CVEv5PackageVersions],
            "references": List[FlawReference],
            "embargoed": bool,
            "created_dt": datetime.datetime,
            "updated_dt": datetime.datetime,
            "classification": FlawClassification,
            "type": FlawType,
            "cve_id": str,
            "impact": Union[BlankEnum, ImpactEnum],
            "component": str,
            "summary": str,
            "statement": str,
            "cwe_id": str,
            "unembargo_dt": datetime.datetime,
            "source": Union[BlankEnum, Source666Enum],
            "reported_dt": datetime.datetime,
            "mitigation": str,
            "cvss2": str,
            "cvss2_score": float,
            "nvd_cvss2": str,
            "cvss3": str,
            "cvss3_score": float,
            "nvd_cvss3": str,
            "is_major_incident": bool,
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.exploit_only_report_data_source_enum import (
    ExploitOnlyReportDataSourceEnum,
)
from ..models.maturity_preliminary_enum import MaturityPreliminaryEnum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="ExploitOnlyReportData")


@attr.s(auto_attribs=True)
class ExploitOnlyReportData(OSIDBModel):
    """ """

    cve: str
    source: ExploitOnlyReportDataSourceEnum
    maturity_preliminary: MaturityPreliminaryEnum
    flaw: bool
    date: Union[Unset, None, datetime.date] = UNSET
    reference: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cve = self.cve
        source: str = UNSET
        if not isinstance(self.source, Unset):

            source = ExploitOnlyReportDataSourceEnum(self.source).value

        maturity_preliminary: int = UNSET
        if not isinstance(self.maturity_preliminary, Unset):

            maturity_preliminary = MaturityPreliminaryEnum(
                self.maturity_preliminary
            ).value

        flaw = self.flaw
        date: Union[Unset, None, str] = UNSET
        if not isinstance(self.date, Unset):
            date = self.date.isoformat() if self.date else None

        reference = self.reference

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if cve is not UNSET:
            field_dict["cve"] = cve
        if source is not UNSET:
            field_dict["source"] = source
        if maturity_preliminary is not UNSET:
            field_dict["maturity_preliminary"] = maturity_preliminary
        if flaw is not UNSET:
            field_dict["flaw"] = flaw
        if date is not UNSET:
            field_dict["date"] = date
        if reference is not UNSET:
            field_dict["reference"] = reference

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cve = d.pop("cve", UNSET)

        _source = d.pop("source", UNSET)
        source: ExploitOnlyReportDataSourceEnum
        if isinstance(_source, Unset):
            source = UNSET
        else:
            source = ExploitOnlyReportDataSourceEnum(_source)

        _maturity_preliminary = d.pop("maturity_preliminary", UNSET)
        maturity_preliminary: MaturityPreliminaryEnum
        if isinstance(_maturity_preliminary, Unset):
            maturity_preliminary = UNSET
        else:
            maturity_preliminary = MaturityPreliminaryEnum(_maturity_preliminary)

        flaw = d.pop("flaw", UNSET)

        _date = d.pop("date", UNSET)
        date: Union[Unset, None, datetime.date]
        if _date is None:
            date = None
        elif isinstance(_date, Unset):
            date = UNSET
        else:
            date = isoparse(_date).date()

        reference = d.pop("reference", UNSET)

        exploit_only_report_data = cls(
            cve=cve,
            source=source,
            maturity_preliminary=maturity_preliminary,
            flaw=flaw,
            date=date,
            reference=reference,
        )

        exploit_only_report_data.additional_properties = d
        return exploit_only_report_data

    @staticmethod
    def get_fields():
        return {
            "cve": str,
            "source": ExploitOnlyReportDataSourceEnum,
            "maturity_preliminary": MaturityPreliminaryEnum,
            "flaw": bool,
            "date": datetime.date,
            "reference": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class OsidbApiV1TrackersListAffectsFlawType(str, Enum):
    VULNERABILITY = "VULNERABILITY"
    WEAKNESS = "WEAKNESS"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class TaskmanApiV1TaskStatusUpdateReason(str, Enum):
    CLOSED = "Closed"
    IN_PROGRESS = "In Progress"
    NEW = "New"
    REFINEMENT = "Refinement"

    def __str__(self) -> str:
        return str(self.value)



""" Contains all the data models used in inputs/outputs """

from .affect import Affect
from .affect_meta_attr import AffectMetaAttr
from .affect_post import AffectPost
from .affect_post_meta_attr import AffectPostMetaAttr
from .affect_report_data import AffectReportData
from .affect_type import AffectType
from .affectedness_enum import AffectednessEnum
from .auth_token_create_response_200 import AuthTokenCreateResponse200
from .auth_token_refresh_create_response_200 import AuthTokenRefreshCreateResponse200
from .auth_token_retrieve_response_200 import AuthTokenRetrieveResponse200
from .auth_token_verify_create_response_200 import AuthTokenVerifyCreateResponse200
from .blank_enum import BlankEnum
from .collectors_api_v1_status_retrieve_response_200 import (
    CollectorsApiV1StatusRetrieveResponse200,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_data import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_error import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemError,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_state import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
)
from .collectors_healthy_retrieve_response_200 import (
    CollectorsHealthyRetrieveResponse200,
)
from .collectors_retrieve_response_200 import CollectorsRetrieveResponse200
from .comment import Comment
from .comment_meta_attr import CommentMetaAttr
from .cv_ev_5_package_versions import CVEv5PackageVersions
from .cv_ev_5_versions import CVEv5Versions
from .epss import EPSS
from .erratum import Erratum
from .exploit_only_report_data import ExploitOnlyReportData
from .exploit_only_report_data_source_enum import ExploitOnlyReportDataSourceEnum
from .exploits_api_v1_collect_update_response_200 import (
    ExploitsApiV1CollectUpdateResponse200,
)
from .exploits_api_v1_cve_map_retrieve_response_200 import (
    ExploitsApiV1CveMapRetrieveResponse200,
)
from .exploits_api_v1_cve_map_retrieve_response_200_cves import (
    ExploitsApiV1CveMapRetrieveResponse200Cves,
)
from .exploits_api_v1_epss_list_response_200 import ExploitsApiV1EpssListResponse200
from .exploits_api_v1_flaw_data_list_response_200 import (
    ExploitsApiV1FlawDataListResponse200,
)
from .exploits_api_v1_report_data_list_response_200 import (
    ExploitsApiV1ReportDataListResponse200,
)
from .exploits_api_v1_report_date_retrieve_response_200 import (
    ExploitsApiV1ReportDateRetrieveResponse200,
)
from .exploits_api_v1_report_date_retrieve_response_200_action_required_item import (
    ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem,
)
from .exploits_api_v1_report_date_retrieve_response_200_no_action_item import (
    ExploitsApiV1ReportDateRetrieveResponse200NoActionItem,
)
from .exploits_api_v1_report_date_retrieve_response_200_not_relevant_item import (
    ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem,
)
from .exploits_api_v1_report_explanations_retrieve_response_200 import (
    ExploitsApiV1ReportExplanationsRetrieveResponse200,
)
from .exploits_api_v1_report_explanations_retrieve_response_200_explanations_item import (
    ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem,
)
from .exploits_api_v1_report_pending_retrieve_response_200 import (
    ExploitsApiV1ReportPendingRetrieveResponse200,
)
from .exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item import (
    ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem,
)
from .exploits_api_v1_status_retrieve_response_200 import (
    ExploitsApiV1StatusRetrieveResponse200,
)
from .exploits_api_v1_supported_products_list_response_200 import (
    ExploitsApiV1SupportedProductsListResponse200,
)
from .flaw import Flaw
from .flaw_classification import FlawClassification
from .flaw_classification_state import FlawClassificationState
from .flaw_comment import FlawComment
from .flaw_comment_post import FlawCommentPost
from .flaw_comment_post_meta_attr import FlawCommentPostMetaAttr
from .flaw_comment_type import FlawCommentType
from .flaw_meta_attr import FlawMetaAttr
from .flaw_meta_type import FlawMetaType
from .flaw_post import FlawPost
from .flaw_post_classification import FlawPostClassification
from .flaw_post_classification_state import FlawPostClassificationState
from .flaw_post_meta_attr import FlawPostMetaAttr
from .flaw_reference import FlawReference
from .flaw_reference_post import FlawReferencePost
from .flaw_reference_type import FlawReferenceType
from .flaw_report_data import FlawReportData
from .flaw_type import FlawType
from .impact_enum import ImpactEnum
from .jira_comment import JiraComment
from .jira_issue import JiraIssue
from .jira_issue_fields import JiraIssueFields
from .jira_issue_query_result import JiraIssueQueryResult
from .jira_issue_type import JiraIssueType
from .jira_user import JiraUser
from .maturity_preliminary_enum import MaturityPreliminaryEnum
from .meta import Meta
from .meta_meta_attr import MetaMetaAttr
from .osidb_api_v1_affects_create_response_201 import OsidbApiV1AffectsCreateResponse201
from .osidb_api_v1_affects_destroy_response_204 import (
    OsidbApiV1AffectsDestroyResponse204,
)
from .osidb_api_v1_affects_list_affectedness import OsidbApiV1AffectsListAffectedness
from .osidb_api_v1_affects_list_flaw_impact import OsidbApiV1AffectsListFlawImpact
from .osidb_api_v1_affects_list_flaw_source import OsidbApiV1AffectsListFlawSource
from .osidb_api_v1_affects_list_flaw_type import OsidbApiV1AffectsListFlawType
from .osidb_api_v1_affects_list_impact import OsidbApiV1AffectsListImpact
from .osidb_api_v1_affects_list_order_item import OsidbApiV1AffectsListOrderItem
from .osidb_api_v1_affects_list_resolution import OsidbApiV1AffectsListResolution
from .osidb_api_v1_affects_list_response_200 import OsidbApiV1AffectsListResponse200
from .osidb_api_v1_affects_list_trackers_type import OsidbApiV1AffectsListTrackersType
from .osidb_api_v1_affects_list_type import OsidbApiV1AffectsListType
from .osidb_api_v1_affects_retrieve_response_200 import (
    OsidbApiV1AffectsRetrieveResponse200,
)
from .osidb_api_v1_affects_update_response_200 import OsidbApiV1AffectsUpdateResponse200
from .osidb_api_v1_flaws_comments_create_response_201 import (
    OsidbApiV1FlawsCommentsCreateResponse201,
)
from .osidb_api_v1_flaws_comments_list_response_200 import (
    OsidbApiV1FlawsCommentsListResponse200,
)
from .osidb_api_v1_flaws_comments_retrieve_response_200 import (
    OsidbApiV1FlawsCommentsRetrieveResponse200,
)
from .osidb_api_v1_flaws_create_response_201 import OsidbApiV1FlawsCreateResponse201
from .osidb_api_v1_flaws_list_affects_affectedness import (
    OsidbApiV1FlawsListAffectsAffectedness,
)
from .osidb_api_v1_flaws_list_affects_impact import OsidbApiV1FlawsListAffectsImpact
from .osidb_api_v1_flaws_list_affects_resolution import (
    OsidbApiV1FlawsListAffectsResolution,
)
from .osidb_api_v1_flaws_list_affects_trackers_type import (
    OsidbApiV1FlawsListAffectsTrackersType,
)
from .osidb_api_v1_flaws_list_affects_type import OsidbApiV1FlawsListAffectsType
from .osidb_api_v1_flaws_list_impact import OsidbApiV1FlawsListImpact
from .osidb_api_v1_flaws_list_order_item import OsidbApiV1FlawsListOrderItem
from .osidb_api_v1_flaws_list_response_200 import OsidbApiV1FlawsListResponse200
from .osidb_api_v1_flaws_list_source import OsidbApiV1FlawsListSource
from .osidb_api_v1_flaws_list_type import OsidbApiV1FlawsListType
from .osidb_api_v1_flaws_references_create_response_201 import (
    OsidbApiV1FlawsReferencesCreateResponse201,
)
from .osidb_api_v1_flaws_references_destroy_response_204 import (
    OsidbApiV1FlawsReferencesDestroyResponse204,
)
from .osidb_api_v1_flaws_references_list_response_200 import (
    OsidbApiV1FlawsReferencesListResponse200,
)
from .osidb_api_v1_flaws_references_retrieve_response_200 import (
    OsidbApiV1FlawsReferencesRetrieveResponse200,
)
from .osidb_api_v1_flaws_references_update_response_200 import (
    OsidbApiV1FlawsReferencesUpdateResponse200,
)
from .osidb_api_v1_flaws_retrieve_response_200 import OsidbApiV1FlawsRetrieveResponse200
from .osidb_api_v1_flaws_update_response_200 import OsidbApiV1FlawsUpdateResponse200
from .osidb_api_v1_manifest_retrieve_response_200 import (
    OsidbApiV1ManifestRetrieveResponse200,
)
from .osidb_api_v1_schema_retrieve_format import OsidbApiV1SchemaRetrieveFormat
from .osidb_api_v1_schema_retrieve_lang import OsidbApiV1SchemaRetrieveLang
from .osidb_api_v1_schema_retrieve_response_200 import (
    OsidbApiV1SchemaRetrieveResponse200,
)
from .osidb_api_v1_status_retrieve_response_200 import (
    OsidbApiV1StatusRetrieveResponse200,
)
from .osidb_api_v1_status_retrieve_response_200_osidb_data import (
    OsidbApiV1StatusRetrieveResponse200OsidbData,
)
from .osidb_api_v1_status_retrieve_response_200_osidb_service import (
    OsidbApiV1StatusRetrieveResponse200OsidbService,
)
from .osidb_api_v1_trackers_list_affects_affectedness import (
    OsidbApiV1TrackersListAffectsAffectedness,
)
from .osidb_api_v1_trackers_list_affects_flaw_impact import (
    OsidbApiV1TrackersListAffectsFlawImpact,
)
from .osidb_api_v1_trackers_list_affects_flaw_source import (
    OsidbApiV1TrackersListAffectsFlawSource,
)
from .osidb_api_v1_trackers_list_affects_flaw_type import (
    OsidbApiV1TrackersListAffectsFlawType,
)
from .osidb_api_v1_trackers_list_affects_impact import (
    OsidbApiV1TrackersListAffectsImpact,
)
from .osidb_api_v1_trackers_list_affects_resolution import (
    OsidbApiV1TrackersListAffectsResolution,
)
from .osidb_api_v1_trackers_list_affects_type import OsidbApiV1TrackersListAffectsType
from .osidb_api_v1_trackers_list_order_item import OsidbApiV1TrackersListOrderItem
from .osidb_api_v1_trackers_list_response_200 import OsidbApiV1TrackersListResponse200
from .osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
from .osidb_api_v1_trackers_retrieve_response_200 import (
    OsidbApiV1TrackersRetrieveResponse200,
)
from .osidb_healthy_retrieve_response_200 import OsidbHealthyRetrieveResponse200
from .osidb_whoami_retrieve_response_200 import OsidbWhoamiRetrieveResponse200
from .osidb_whoami_retrieve_response_200_profile import (
    OsidbWhoamiRetrieveResponse200Profile,
)
from .osim_api_v1_workflows_adjust_create_response_200 import (
    OsimApiV1WorkflowsAdjustCreateResponse200,
)
from .osim_api_v1_workflows_retrieve_2_response_200 import (
    OsimApiV1WorkflowsRetrieve2Response200,
)
from .osim_api_v1_workflows_retrieve_response_200 import (
    OsimApiV1WorkflowsRetrieveResponse200,
)
from .osim_healthy_retrieve_response_200 import OsimHealthyRetrieveResponse200
from .osim_retrieve_response_200 import OsimRetrieveResponse200
from .paginated_affect_list import PaginatedAffectList
from .paginated_epss_list import PaginatedEPSSList
from .paginated_exploit_only_report_data_list import PaginatedExploitOnlyReportDataList
from .paginated_flaw_comment_list import PaginatedFlawCommentList
from .paginated_flaw_list import PaginatedFlawList
from .paginated_flaw_reference_list import PaginatedFlawReferenceList
from .paginated_flaw_report_data_list import PaginatedFlawReportDataList
from .paginated_supported_products_list import PaginatedSupportedProductsList
from .paginated_tracker_list import PaginatedTrackerList
from .resolution_enum import ResolutionEnum
from .source_666_enum import Source666Enum
from .status_enum import StatusEnum
from .supported_products import SupportedProducts
from .taskman_api_v1_group_create_response_200 import TaskmanApiV1GroupCreateResponse200
from .taskman_api_v1_group_retrieve_response_200 import (
    TaskmanApiV1GroupRetrieveResponse200,
)
from .taskman_api_v1_group_update_response_200 import TaskmanApiV1GroupUpdateResponse200
from .taskman_api_v1_task_assignee_retrieve_response_200 import (
    TaskmanApiV1TaskAssigneeRetrieveResponse200,
)
from .taskman_api_v1_task_assignee_update_response_200 import (
    TaskmanApiV1TaskAssigneeUpdateResponse200,
)
from .taskman_api_v1_task_comment_create_response_200 import (
    TaskmanApiV1TaskCommentCreateResponse200,
)
from .taskman_api_v1_task_comment_update_response_200 import (
    TaskmanApiV1TaskCommentUpdateResponse200,
)
from .taskman_api_v1_task_flaw_create_response_200 import (
    TaskmanApiV1TaskFlawCreateResponse200,
)
from .taskman_api_v1_task_flaw_retrieve_response_200 import (
    TaskmanApiV1TaskFlawRetrieveResponse200,
)
from .taskman_api_v1_task_flaw_update_response_200 import (
    TaskmanApiV1TaskFlawUpdateResponse200,
)
from .taskman_api_v1_task_retrieve_response_200 import (
    TaskmanApiV1TaskRetrieveResponse200,
)
from .taskman_api_v1_task_status_update_reason import TaskmanApiV1TaskStatusUpdateReason
from .taskman_api_v1_task_status_update_resolution import (
    TaskmanApiV1TaskStatusUpdateResolution,
)
from .taskman_api_v1_task_status_update_response_200 import (
    TaskmanApiV1TaskStatusUpdateResponse200,
)
from .taskman_api_v1_task_status_update_status import TaskmanApiV1TaskStatusUpdateStatus
from .taskman_api_v1_task_unassigned_retrieve_response_200 import (
    TaskmanApiV1TaskUnassignedRetrieveResponse200,
)
from .taskman_healthy_retrieve_response_200 import TaskmanHealthyRetrieveResponse200
from .token_obtain_pair import TokenObtainPair
from .token_refresh import TokenRefresh
from .token_verify import TokenVerify
from .tracker import Tracker
from .tracker_meta_attr import TrackerMetaAttr
from .tracker_report_data import TrackerReportData
from .tracker_type import TrackerType



import datetime
from typing import Any, Dict, List, Optional, Union

import requests

from ...client import AuthenticatedClient
from ...models.osidb_api_v1_trackers_list_affects_affectedness import (
    OsidbApiV1TrackersListAffectsAffectedness,
)
from ...models.osidb_api_v1_trackers_list_affects_flaw_impact import (
    OsidbApiV1TrackersListAffectsFlawImpact,
)
from ...models.osidb_api_v1_trackers_list_affects_flaw_source import (
    OsidbApiV1TrackersListAffectsFlawSource,
)
from ...models.osidb_api_v1_trackers_list_affects_flaw_type import (
    OsidbApiV1TrackersListAffectsFlawType,
)
from ...models.osidb_api_v1_trackers_list_affects_impact import (
    OsidbApiV1TrackersListAffectsImpact,
)
from ...models.osidb_api_v1_trackers_list_affects_resolution import (
    OsidbApiV1TrackersListAffectsResolution,
)
from ...models.osidb_api_v1_trackers_list_affects_type import (
    OsidbApiV1TrackersListAffectsType,
)
from ...models.osidb_api_v1_trackers_list_order_item import (
    OsidbApiV1TrackersListOrderItem,
)
from ...models.osidb_api_v1_trackers_list_response_200 import (
    OsidbApiV1TrackersListResponse200,
)
from ...models.osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {
    "affects__affectedness": OsidbApiV1TrackersListAffectsAffectedness,
    "affects__created_dt": datetime.datetime,
    "affects__created_dt__date": datetime.date,
    "affects__created_dt__date__gte": datetime.date,
    "affects__created_dt__date__lte": datetime.date,
    "affects__created_dt__gt": datetime.datetime,
    "affects__created_dt__gte": datetime.datetime,
    "affects__created_dt__lt": datetime.datetime,
    "affects__created_dt__lte": datetime.datetime,
    "affects__cvss2": str,
    "affects__cvss2_score": float,
    "affects__cvss2_score__gt": float,
    "affects__cvss2_score__gte": float,
    "affects__cvss2_score__lt": float,
    "affects__cvss2_score__lte": float,
    "affects__cvss3": str,
    "affects__cvss3_score": float,
    "affects__cvss3_score__gt": float,
    "affects__cvss3_score__gte": float,
    "affects__cvss3_score__lt": float,
    "affects__cvss3_score__lte": float,
    "affects__embargoed": bool,
    "affects__flaw__component": str,
    "affects__flaw__created_dt": datetime.datetime,
    "affects__flaw__created_dt__date": datetime.date,
    "affects__flaw__created_dt__date__gte": datetime.date,
    "affects__flaw__created_dt__date__lte": datetime.date,
    "affects__flaw__created_dt__gt": datetime.datetime,
    "affects__flaw__created_dt__gte": datetime.datetime,
    "affects__flaw__created_dt__lt": datetime.datetime,
    "affects__flaw__created_dt__lte": datetime.datetime,
    "affects__flaw__cve_id": str,
    "affects__flaw__cvss2": str,
    "affects__flaw__cvss2_score": float,
    "affects__flaw__cvss2_score__gt": float,
    "affects__flaw__cvss2_score__gte": float,
    "affects__flaw__cvss2_score__lt": float,
    "affects__flaw__cvss2_score__lte": float,
    "affects__flaw__cvss3": str,
    "affects__flaw__cvss3_score": float,
    "affects__flaw__cvss3_score__gt": float,
    "affects__flaw__cvss3_score__gte": float,
    "affects__flaw__cvss3_score__lt": float,
    "affects__flaw__cvss3_score__lte": float,
    "affects__flaw__cwe_id": str,
    "affects__flaw__embargoed": bool,
    "affects__flaw__impact": OsidbApiV1TrackersListAffectsFlawImpact,
    "affects__flaw__is_major_incident": bool,
    "affects__flaw__nvd_cvss2": str,
    "affects__flaw__nvd_cvss3": str,
    "affects__flaw__reported_dt": datetime.datetime,
    "affects__flaw__reported_dt__date": datetime.date,
    "affects__flaw__reported_dt__date__gte": datetime.date,
    "affects__flaw__reported_dt__date__lte": datetime.date,
    "affects__flaw__reported_dt__gt": datetime.datetime,
    "affects__flaw__reported_dt__gte": datetime.datetime,
    "affects__flaw__reported_dt__lt": datetime.datetime,
    "affects__flaw__reported_dt__lte": datetime.datetime,
    "affects__flaw__source": OsidbApiV1TrackersListAffectsFlawSource,
    "affects__flaw__type": OsidbApiV1TrackersListAffectsFlawType,
    "affects__flaw__unembargo_dt": datetime.datetime,
    "affects__flaw__updated_dt": datetime.datetime,
    "affects__flaw__updated_dt__date": datetime.date,
    "affects__flaw__updated_dt__date__gte": datetime.date,
    "affects__flaw__updated_dt__date__lte": datetime.date,
    "affects__flaw__updated_dt__gt": datetime.datetime,
    "affects__flaw__updated_dt__gte": datetime.datetime,
    "affects__flaw__updated_dt__lt": datetime.datetime,
    "affects__flaw__updated_dt__lte": datetime.datetime,
    "affects__flaw__uuid": str,
    "affects__impact": OsidbApiV1TrackersListAffectsImpact,
    "affects__ps_component": str,
    "affects__ps_module": str,
    "affects__resolution": OsidbApiV1TrackersListAffectsResolution,
    "affects__type": OsidbApiV1TrackersListAffectsType,
    "affects__updated_dt": datetime.datetime,
    "affects__updated_dt__date": datetime.date,
    "affects__updated_dt__date__gte": datetime.date,
    "affects__updated_dt__date__lte": datetime.date,
    "affects__updated_dt__gt": datetime.datetime,
    "affects__updated_dt__gte": datetime.datetime,
    "affects__updated_dt__lt": datetime.datetime,
    "affects__updated_dt__lte": datetime.datetime,
    "affects__uuid": str,
    "created_dt": datetime.datetime,
    "created_dt__date": datetime.date,
    "created_dt__date__gte": datetime.date,
    "created_dt__date__lte": datetime.date,
    "created_dt__gt": datetime.datetime,
    "created_dt__gte": datetime.datetime,
    "created_dt__lt": datetime.datetime,
    "created_dt__lte": datetime.datetime,
    "embargoed": bool,
    "exclude_fields": List[str],
    "external_system_id": str,
    "include_fields": List[str],
    "include_meta_attr": List[str],
    "limit": int,
    "offset": int,
    "order": List[OsidbApiV1TrackersListOrderItem],
    "ps_update_stream": str,
    "resolution": str,
    "status": str,
    "type": OsidbApiV1TrackersListType,
    "updated_dt": datetime.datetime,
    "updated_dt__date": datetime.date,
    "updated_dt__date__gte": datetime.date,
    "updated_dt__date__lte": datetime.date,
    "updated_dt__gt": datetime.datetime,
    "updated_dt__gte": datetime.datetime,
    "updated_dt__lt": datetime.datetime,
    "updated_dt__lte": datetime.datetime,
    "uuid": str,
}


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[
        Unset, None, OsidbApiV1TrackersListAffectsAffectedness
    ] = UNSET,
    affects_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_cvss2: Union[Unset, None, str] = UNSET,
    affects_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_cvss3: Union[Unset, None, str] = UNSET,
    affects_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_component: Union[Unset, None, str] = UNSET,
    affects_flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cwe_id: Union[Unset, None, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_impact: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawImpact
    ] = UNSET,
    affects_flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    affects_flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_source: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawSource
    ] = UNSET,
    affects_flaw_type: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawType
    ] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, None, str] = UNSET,
    affects_impact: Union[Unset, None, OsidbApiV1TrackersListAffectsImpact] = UNSET,
    affects_ps_component: Union[Unset, None, str] = UNSET,
    affects_ps_module: Union[Unset, None, str] = UNSET,
    affects_resolution: Union[
        Unset, None, OsidbApiV1TrackersListAffectsResolution
    ] = UNSET,
    affects_type: Union[Unset, None, OsidbApiV1TrackersListAffectsType] = UNSET,
    affects_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, None, str] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    external_system_id: Union[Unset, None, str] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    status: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/osidb/api/v1/trackers".format(
        client.base_url,
    )

    headers: Dict[str, Any] = client.get_headers()

    json_affects_affectedness: Union[Unset, None, str] = UNSET
    if not isinstance(affects_affectedness, Unset):

        json_affects_affectedness = (
            OsidbApiV1TrackersListAffectsAffectedness(affects_affectedness).value
            if affects_affectedness
            else None
        )

    json_affects_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt, Unset):
        json_affects_created_dt = (
            affects_created_dt.isoformat() if affects_created_dt else None
        )

    json_affects_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_date, Unset):
        json_affects_created_dt_date = (
            affects_created_dt_date.isoformat() if affects_created_dt_date else None
        )

    json_affects_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_date_gte, Unset):
        json_affects_created_dt_date_gte = (
            affects_created_dt_date_gte.isoformat()
            if affects_created_dt_date_gte
            else None
        )

    json_affects_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_date_lte, Unset):
        json_affects_created_dt_date_lte = (
            affects_created_dt_date_lte.isoformat()
            if affects_created_dt_date_lte
            else None
        )

    json_affects_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_gt, Unset):
        json_affects_created_dt_gt = (
            affects_created_dt_gt.isoformat() if affects_created_dt_gt else None
        )

    json_affects_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_gte, Unset):
        json_affects_created_dt_gte = (
            affects_created_dt_gte.isoformat() if affects_created_dt_gte else None
        )

    json_affects_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_lt, Unset):
        json_affects_created_dt_lt = (
            affects_created_dt_lt.isoformat() if affects_created_dt_lt else None
        )

    json_affects_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_created_dt_lte, Unset):
        json_affects_created_dt_lte = (
            affects_created_dt_lte.isoformat() if affects_created_dt_lte else None
        )

    json_affects_flaw_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt, Unset):
        json_affects_flaw_created_dt = (
            affects_flaw_created_dt.isoformat() if affects_flaw_created_dt else None
        )

    json_affects_flaw_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date, Unset):
        json_affects_flaw_created_dt_date = (
            affects_flaw_created_dt_date.isoformat()
            if affects_flaw_created_dt_date
            else None
        )

    json_affects_flaw_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date_gte, Unset):
        json_affects_flaw_created_dt_date_gte = (
            affects_flaw_created_dt_date_gte.isoformat()
            if affects_flaw_created_dt_date_gte
            else None
        )

    json_affects_flaw_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date_lte, Unset):
        json_affects_flaw_created_dt_date_lte = (
            affects_flaw_created_dt_date_lte.isoformat()
            if affects_flaw_created_dt_date_lte
            else None
        )

    json_affects_flaw_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_gt, Unset):
        json_affects_flaw_created_dt_gt = (
            affects_flaw_created_dt_gt.isoformat()
            if affects_flaw_created_dt_gt
            else None
        )

    json_affects_flaw_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_gte, Unset):
        json_affects_flaw_created_dt_gte = (
            affects_flaw_created_dt_gte.isoformat()
            if affects_flaw_created_dt_gte
            else None
        )

    json_affects_flaw_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_lt, Unset):
        json_affects_flaw_created_dt_lt = (
            affects_flaw_created_dt_lt.isoformat()
            if affects_flaw_created_dt_lt
            else None
        )

    json_affects_flaw_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_created_dt_lte, Unset):
        json_affects_flaw_created_dt_lte = (
            affects_flaw_created_dt_lte.isoformat()
            if affects_flaw_created_dt_lte
            else None
        )

    json_affects_flaw_impact: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_impact, Unset):

        json_affects_flaw_impact = (
            OsidbApiV1TrackersListAffectsFlawImpact(affects_flaw_impact).value
            if affects_flaw_impact
            else None
        )

    json_affects_flaw_reported_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt, Unset):
        json_affects_flaw_reported_dt = (
            affects_flaw_reported_dt.isoformat() if affects_flaw_reported_dt else None
        )

    json_affects_flaw_reported_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date, Unset):
        json_affects_flaw_reported_dt_date = (
            affects_flaw_reported_dt_date.isoformat()
            if affects_flaw_reported_dt_date
            else None
        )

    json_affects_flaw_reported_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date_gte, Unset):
        json_affects_flaw_reported_dt_date_gte = (
            affects_flaw_reported_dt_date_gte.isoformat()
            if affects_flaw_reported_dt_date_gte
            else None
        )

    json_affects_flaw_reported_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date_lte, Unset):
        json_affects_flaw_reported_dt_date_lte = (
            affects_flaw_reported_dt_date_lte.isoformat()
            if affects_flaw_reported_dt_date_lte
            else None
        )

    json_affects_flaw_reported_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_gt, Unset):
        json_affects_flaw_reported_dt_gt = (
            affects_flaw_reported_dt_gt.isoformat()
            if affects_flaw_reported_dt_gt
            else None
        )

    json_affects_flaw_reported_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_gte, Unset):
        json_affects_flaw_reported_dt_gte = (
            affects_flaw_reported_dt_gte.isoformat()
            if affects_flaw_reported_dt_gte
            else None
        )

    json_affects_flaw_reported_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_lt, Unset):
        json_affects_flaw_reported_dt_lt = (
            affects_flaw_reported_dt_lt.isoformat()
            if affects_flaw_reported_dt_lt
            else None
        )

    json_affects_flaw_reported_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_lte, Unset):
        json_affects_flaw_reported_dt_lte = (
            affects_flaw_reported_dt_lte.isoformat()
            if affects_flaw_reported_dt_lte
            else None
        )

    json_affects_flaw_source: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_source, Unset):

        json_affects_flaw_source = (
            OsidbApiV1TrackersListAffectsFlawSource(affects_flaw_source).value
            if affects_flaw_source
            else None
        )

    json_affects_flaw_type: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_type, Unset):

        json_affects_flaw_type = (
            OsidbApiV1TrackersListAffectsFlawType(affects_flaw_type).value
            if affects_flaw_type
            else None
        )

    json_affects_flaw_unembargo_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_unembargo_dt, Unset):
        json_affects_flaw_unembargo_dt = (
            affects_flaw_unembargo_dt.isoformat() if affects_flaw_unembargo_dt else None
        )

    json_affects_flaw_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt, Unset):
        json_affects_flaw_updated_dt = (
            affects_flaw_updated_dt.isoformat() if affects_flaw_updated_dt else None
        )

    json_affects_flaw_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date, Unset):
        json_affects_flaw_updated_dt_date = (
            affects_flaw_updated_dt_date.isoformat()
            if affects_flaw_updated_dt_date
            else None
        )

    json_affects_flaw_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date_gte, Unset):
        json_affects_flaw_updated_dt_date_gte = (
            affects_flaw_updated_dt_date_gte.isoformat()
            if affects_flaw_updated_dt_date_gte
            else None
        )

    json_affects_flaw_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date_lte, Unset):
        json_affects_flaw_updated_dt_date_lte = (
            affects_flaw_updated_dt_date_lte.isoformat()
            if affects_flaw_updated_dt_date_lte
            else None
        )

    json_affects_flaw_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_gt, Unset):
        json_affects_flaw_updated_dt_gt = (
            affects_flaw_updated_dt_gt.isoformat()
            if affects_flaw_updated_dt_gt
            else None
        )

    json_affects_flaw_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_gte, Unset):
        json_affects_flaw_updated_dt_gte = (
            affects_flaw_updated_dt_gte.isoformat()
            if affects_flaw_updated_dt_gte
            else None
        )

    json_affects_flaw_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_lt, Unset):
        json_affects_flaw_updated_dt_lt = (
            affects_flaw_updated_dt_lt.isoformat()
            if affects_flaw_updated_dt_lt
            else None
        )

    json_affects_flaw_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_lte, Unset):
        json_affects_flaw_updated_dt_lte = (
            affects_flaw_updated_dt_lte.isoformat()
            if affects_flaw_updated_dt_lte
            else None
        )

    json_affects_impact: Union[Unset, None, str] = UNSET
    if not isinstance(affects_impact, Unset):

        json_affects_impact = (
            OsidbApiV1TrackersListAffectsImpact(affects_impact).value
            if affects_impact
            else None
        )

    json_affects_resolution: Union[Unset, None, str] = UNSET
    if not isinstance(affects_resolution, Unset):

        json_affects_resolution = (
            OsidbApiV1TrackersListAffectsResolution(affects_resolution).value
            if affects_resolution
            else None
        )

    json_affects_type: Union[Unset, None, str] = UNSET
    if not isinstance(affects_type, Unset):

        json_affects_type = (
            OsidbApiV1TrackersListAffectsType(affects_type).value
            if affects_type
            else None
        )

    json_affects_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt, Unset):
        json_affects_updated_dt = (
            affects_updated_dt.isoformat() if affects_updated_dt else None
        )

    json_affects_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_date, Unset):
        json_affects_updated_dt_date = (
            affects_updated_dt_date.isoformat() if affects_updated_dt_date else None
        )

    json_affects_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_date_gte, Unset):
        json_affects_updated_dt_date_gte = (
            affects_updated_dt_date_gte.isoformat()
            if affects_updated_dt_date_gte
            else None
        )

    json_affects_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_date_lte, Unset):
        json_affects_updated_dt_date_lte = (
            affects_updated_dt_date_lte.isoformat()
            if affects_updated_dt_date_lte
            else None
        )

    json_affects_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_gt, Unset):
        json_affects_updated_dt_gt = (
            affects_updated_dt_gt.isoformat() if affects_updated_dt_gt else None
        )

    json_affects_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_gte, Unset):
        json_affects_updated_dt_gte = (
            affects_updated_dt_gte.isoformat() if affects_updated_dt_gte else None
        )

    json_affects_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_lt, Unset):
        json_affects_updated_dt_lt = (
            affects_updated_dt_lt.isoformat() if affects_updated_dt_lt else None
        )

    json_affects_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(affects_updated_dt_lte, Unset):
        json_affects_updated_dt_lte = (
            affects_updated_dt_lte.isoformat() if affects_updated_dt_lte else None
        )

    json_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt, Unset):
        json_created_dt = created_dt.isoformat() if created_dt else None

    json_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date, Unset):
        json_created_dt_date = created_dt_date.isoformat() if created_dt_date else None

    json_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date_gte, Unset):
        json_created_dt_date_gte = (
            created_dt_date_gte.isoformat() if created_dt_date_gte else None
        )

    json_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date_lte, Unset):
        json_created_dt_date_lte = (
            created_dt_date_lte.isoformat() if created_dt_date_lte else None
        )

    json_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_gt, Unset):
        json_created_dt_gt = created_dt_gt.isoformat() if created_dt_gt else None

    json_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_gte, Unset):
        json_created_dt_gte = created_dt_gte.isoformat() if created_dt_gte else None

    json_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_lt, Unset):
        json_created_dt_lt = created_dt_lt.isoformat() if created_dt_lt else None

    json_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_lte, Unset):
        json_created_dt_lte = created_dt_lte.isoformat() if created_dt_lte else None

    json_exclude_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_fields, Unset):
        if exclude_fields is None:
            json_exclude_fields = None
        else:
            json_exclude_fields = exclude_fields

    json_include_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_fields, Unset):
        if include_fields is None:
            json_include_fields = None
        else:
            json_include_fields = include_fields

    json_include_meta_attr: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_meta_attr, Unset):
        if include_meta_attr is None:
            json_include_meta_attr = None
        else:
            json_include_meta_attr = include_meta_attr

    json_order: Union[Unset, None, List[str]] = UNSET
    if not isinstance(order, Unset):
        if order is None:
            json_order = None
        else:
            json_order = []
            for order_item_data in order:
                order_item: str = UNSET
                if not isinstance(order_item_data, Unset):

                    order_item = OsidbApiV1TrackersListOrderItem(order_item_data).value

                json_order.append(order_item)

    json_type: Union[Unset, None, str] = UNSET
    if not isinstance(type, Unset):

        json_type = OsidbApiV1TrackersListType(type).value if type else None

    json_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt, Unset):
        json_updated_dt = updated_dt.isoformat() if updated_dt else None

    json_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date, Unset):
        json_updated_dt_date = updated_dt_date.isoformat() if updated_dt_date else None

    json_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date_gte, Unset):
        json_updated_dt_date_gte = (
            updated_dt_date_gte.isoformat() if updated_dt_date_gte else None
        )

    json_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date_lte, Unset):
        json_updated_dt_date_lte = (
            updated_dt_date_lte.isoformat() if updated_dt_date_lte else None
        )

    json_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_gt, Unset):
        json_updated_dt_gt = updated_dt_gt.isoformat() if updated_dt_gt else None

    json_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_gte, Unset):
        json_updated_dt_gte = updated_dt_gte.isoformat() if updated_dt_gte else None

    json_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_lt, Unset):
        json_updated_dt_lt = updated_dt_lt.isoformat() if updated_dt_lt else None

    json_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_lte, Unset):
        json_updated_dt_lte = updated_dt_lte.isoformat() if updated_dt_lte else None

    params: Dict[str, Any] = {
        "affects__affectedness": json_affects_affectedness,
        "affects__created_dt": json_affects_created_dt,
        "affects__created_dt__date": json_affects_created_dt_date,
        "affects__created_dt__date__gte": json_affects_created_dt_date_gte,
        "affects__created_dt__date__lte": json_affects_created_dt_date_lte,
        "affects__created_dt__gt": json_affects_created_dt_gt,
        "affects__created_dt__gte": json_affects_created_dt_gte,
        "affects__created_dt__lt": json_affects_created_dt_lt,
        "affects__created_dt__lte": json_affects_created_dt_lte,
        "affects__cvss2": affects_cvss2,
        "affects__cvss2_score": affects_cvss2_score,
        "affects__cvss2_score__gt": affects_cvss2_score_gt,
        "affects__cvss2_score__gte": affects_cvss2_score_gte,
        "affects__cvss2_score__lt": affects_cvss2_score_lt,
        "affects__cvss2_score__lte": affects_cvss2_score_lte,
        "affects__cvss3": affects_cvss3,
        "affects__cvss3_score": affects_cvss3_score,
        "affects__cvss3_score__gt": affects_cvss3_score_gt,
        "affects__cvss3_score__gte": affects_cvss3_score_gte,
        "affects__cvss3_score__lt": affects_cvss3_score_lt,
        "affects__cvss3_score__lte": affects_cvss3_score_lte,
        "affects__embargoed": affects_embargoed,
        "affects__flaw__component": affects_flaw_component,
        "affects__flaw__created_dt": json_affects_flaw_created_dt,
        "affects__flaw__created_dt__date": json_affects_flaw_created_dt_date,
        "affects__flaw__created_dt__date__gte": json_affects_flaw_created_dt_date_gte,
        "affects__flaw__created_dt__date__lte": json_affects_flaw_created_dt_date_lte,
        "affects__flaw__created_dt__gt": json_affects_flaw_created_dt_gt,
        "affects__flaw__created_dt__gte": json_affects_flaw_created_dt_gte,
        "affects__flaw__created_dt__lt": json_affects_flaw_created_dt_lt,
        "affects__flaw__created_dt__lte": json_affects_flaw_created_dt_lte,
        "affects__flaw__cve_id": affects_flaw_cve_id,
        "affects__flaw__cvss2": affects_flaw_cvss2,
        "affects__flaw__cvss2_score": affects_flaw_cvss2_score,
        "affects__flaw__cvss2_score__gt": affects_flaw_cvss2_score_gt,
        "affects__flaw__cvss2_score__gte": affects_flaw_cvss2_score_gte,
        "affects__flaw__cvss2_score__lt": affects_flaw_cvss2_score_lt,
        "affects__flaw__cvss2_score__lte": affects_flaw_cvss2_score_lte,
        "affects__flaw__cvss3": affects_flaw_cvss3,
        "affects__flaw__cvss3_score": affects_flaw_cvss3_score,
        "affects__flaw__cvss3_score__gt": affects_flaw_cvss3_score_gt,
        "affects__flaw__cvss3_score__gte": affects_flaw_cvss3_score_gte,
        "affects__flaw__cvss3_score__lt": affects_flaw_cvss3_score_lt,
        "affects__flaw__cvss3_score__lte": affects_flaw_cvss3_score_lte,
        "affects__flaw__cwe_id": affects_flaw_cwe_id,
        "affects__flaw__embargoed": affects_flaw_embargoed,
        "affects__flaw__impact": json_affects_flaw_impact,
        "affects__flaw__is_major_incident": affects_flaw_is_major_incident,
        "affects__flaw__nvd_cvss2": affects_flaw_nvd_cvss2,
        "affects__flaw__nvd_cvss3": affects_flaw_nvd_cvss3,
        "affects__flaw__reported_dt": json_affects_flaw_reported_dt,
        "affects__flaw__reported_dt__date": json_affects_flaw_reported_dt_date,
        "affects__flaw__reported_dt__date__gte": json_affects_flaw_reported_dt_date_gte,
        "affects__flaw__reported_dt__date__lte": json_affects_flaw_reported_dt_date_lte,
        "affects__flaw__reported_dt__gt": json_affects_flaw_reported_dt_gt,
        "affects__flaw__reported_dt__gte": json_affects_flaw_reported_dt_gte,
        "affects__flaw__reported_dt__lt": json_affects_flaw_reported_dt_lt,
        "affects__flaw__reported_dt__lte": json_affects_flaw_reported_dt_lte,
        "affects__flaw__source": json_affects_flaw_source,
        "affects__flaw__type": json_affects_flaw_type,
        "affects__flaw__unembargo_dt": json_affects_flaw_unembargo_dt,
        "affects__flaw__updated_dt": json_affects_flaw_updated_dt,
        "affects__flaw__updated_dt__date": json_affects_flaw_updated_dt_date,
        "affects__flaw__updated_dt__date__gte": json_affects_flaw_updated_dt_date_gte,
        "affects__flaw__updated_dt__date__lte": json_affects_flaw_updated_dt_date_lte,
        "affects__flaw__updated_dt__gt": json_affects_flaw_updated_dt_gt,
        "affects__flaw__updated_dt__gte": json_affects_flaw_updated_dt_gte,
        "affects__flaw__updated_dt__lt": json_affects_flaw_updated_dt_lt,
        "affects__flaw__updated_dt__lte": json_affects_flaw_updated_dt_lte,
        "affects__flaw__uuid": affects_flaw_uuid,
        "affects__impact": json_affects_impact,
        "affects__ps_component": affects_ps_component,
        "affects__ps_module": affects_ps_module,
        "affects__resolution": json_affects_resolution,
        "affects__type": json_affects_type,
        "affects__updated_dt": json_affects_updated_dt,
        "affects__updated_dt__date": json_affects_updated_dt_date,
        "affects__updated_dt__date__gte": json_affects_updated_dt_date_gte,
        "affects__updated_dt__date__lte": json_affects_updated_dt_date_lte,
        "affects__updated_dt__gt": json_affects_updated_dt_gt,
        "affects__updated_dt__gte": json_affects_updated_dt_gte,
        "affects__updated_dt__lt": json_affects_updated_dt_lt,
        "affects__updated_dt__lte": json_affects_updated_dt_lte,
        "affects__uuid": affects_uuid,
        "created_dt": json_created_dt,
        "created_dt__date": json_created_dt_date,
        "created_dt__date__gte": json_created_dt_date_gte,
        "created_dt__date__lte": json_created_dt_date_lte,
        "created_dt__gt": json_created_dt_gt,
        "created_dt__gte": json_created_dt_gte,
        "created_dt__lt": json_created_dt_lt,
        "created_dt__lte": json_created_dt_lte,
        "embargoed": embargoed,
        "exclude_fields": json_exclude_fields,
        "external_system_id": external_system_id,
        "include_fields": json_include_fields,
        "include_meta_attr": json_include_meta_attr,
        "limit": limit,
        "offset": offset,
        "order": json_order,
        "ps_update_stream": ps_update_stream,
        "resolution": resolution,
        "status": status,
        "type": json_type,
        "updated_dt": json_updated_dt,
        "updated_dt__date": json_updated_dt_date,
        "updated_dt__date__gte": json_updated_dt_date_gte,
        "updated_dt__date__lte": json_updated_dt_date_lte,
        "updated_dt__gt": json_updated_dt_gt,
        "updated_dt__gte": json_updated_dt_gte,
        "updated_dt__lt": json_updated_dt_lt,
        "updated_dt__lte": json_updated_dt_lte,
        "uuid": uuid,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "params": params,
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[OsidbApiV1TrackersListResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1TrackersListResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1TrackersListResponse200.from_dict(_response_200)

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[OsidbApiV1TrackersListResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[
        Unset, None, OsidbApiV1TrackersListAffectsAffectedness
    ] = UNSET,
    affects_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_cvss2: Union[Unset, None, str] = UNSET,
    affects_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_cvss3: Union[Unset, None, str] = UNSET,
    affects_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_component: Union[Unset, None, str] = UNSET,
    affects_flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cwe_id: Union[Unset, None, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_impact: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawImpact
    ] = UNSET,
    affects_flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    affects_flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_source: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawSource
    ] = UNSET,
    affects_flaw_type: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawType
    ] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, None, str] = UNSET,
    affects_impact: Union[Unset, None, OsidbApiV1TrackersListAffectsImpact] = UNSET,
    affects_ps_component: Union[Unset, None, str] = UNSET,
    affects_ps_module: Union[Unset, None, str] = UNSET,
    affects_resolution: Union[
        Unset, None, OsidbApiV1TrackersListAffectsResolution
    ] = UNSET,
    affects_type: Union[Unset, None, OsidbApiV1TrackersListAffectsType] = UNSET,
    affects_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, None, str] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    external_system_id: Union[Unset, None, str] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    status: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Response[OsidbApiV1TrackersListResponse200]:
    kwargs = _get_kwargs(
        client=client,
        affects_affectedness=affects_affectedness,
        affects_created_dt=affects_created_dt,
        affects_created_dt_date=affects_created_dt_date,
        affects_created_dt_date_gte=affects_created_dt_date_gte,
        affects_created_dt_date_lte=affects_created_dt_date_lte,
        affects_created_dt_gt=affects_created_dt_gt,
        affects_created_dt_gte=affects_created_dt_gte,
        affects_created_dt_lt=affects_created_dt_lt,
        affects_created_dt_lte=affects_created_dt_lte,
        affects_cvss2=affects_cvss2,
        affects_cvss2_score=affects_cvss2_score,
        affects_cvss2_score_gt=affects_cvss2_score_gt,
        affects_cvss2_score_gte=affects_cvss2_score_gte,
        affects_cvss2_score_lt=affects_cvss2_score_lt,
        affects_cvss2_score_lte=affects_cvss2_score_lte,
        affects_cvss3=affects_cvss3,
        affects_cvss3_score=affects_cvss3_score,
        affects_cvss3_score_gt=affects_cvss3_score_gt,
        affects_cvss3_score_gte=affects_cvss3_score_gte,
        affects_cvss3_score_lt=affects_cvss3_score_lt,
        affects_cvss3_score_lte=affects_cvss3_score_lte,
        affects_embargoed=affects_embargoed,
        affects_flaw_component=affects_flaw_component,
        affects_flaw_created_dt=affects_flaw_created_dt,
        affects_flaw_created_dt_date=affects_flaw_created_dt_date,
        affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
        affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
        affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
        affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
        affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
        affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
        affects_flaw_cve_id=affects_flaw_cve_id,
        affects_flaw_cvss2=affects_flaw_cvss2,
        affects_flaw_cvss2_score=affects_flaw_cvss2_score,
        affects_flaw_cvss2_score_gt=affects_flaw_cvss2_score_gt,
        affects_flaw_cvss2_score_gte=affects_flaw_cvss2_score_gte,
        affects_flaw_cvss2_score_lt=affects_flaw_cvss2_score_lt,
        affects_flaw_cvss2_score_lte=affects_flaw_cvss2_score_lte,
        affects_flaw_cvss3=affects_flaw_cvss3,
        affects_flaw_cvss3_score=affects_flaw_cvss3_score,
        affects_flaw_cvss3_score_gt=affects_flaw_cvss3_score_gt,
        affects_flaw_cvss3_score_gte=affects_flaw_cvss3_score_gte,
        affects_flaw_cvss3_score_lt=affects_flaw_cvss3_score_lt,
        affects_flaw_cvss3_score_lte=affects_flaw_cvss3_score_lte,
        affects_flaw_cwe_id=affects_flaw_cwe_id,
        affects_flaw_embargoed=affects_flaw_embargoed,
        affects_flaw_impact=affects_flaw_impact,
        affects_flaw_is_major_incident=affects_flaw_is_major_incident,
        affects_flaw_nvd_cvss2=affects_flaw_nvd_cvss2,
        affects_flaw_nvd_cvss3=affects_flaw_nvd_cvss3,
        affects_flaw_reported_dt=affects_flaw_reported_dt,
        affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
        affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
        affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
        affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
        affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
        affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
        affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
        affects_flaw_source=affects_flaw_source,
        affects_flaw_type=affects_flaw_type,
        affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
        affects_flaw_updated_dt=affects_flaw_updated_dt,
        affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
        affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
        affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
        affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
        affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
        affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
        affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
        affects_flaw_uuid=affects_flaw_uuid,
        affects_impact=affects_impact,
        affects_ps_component=affects_ps_component,
        affects_ps_module=affects_ps_module,
        affects_resolution=affects_resolution,
        affects_type=affects_type,
        affects_updated_dt=affects_updated_dt,
        affects_updated_dt_date=affects_updated_dt_date,
        affects_updated_dt_date_gte=affects_updated_dt_date_gte,
        affects_updated_dt_date_lte=affects_updated_dt_date_lte,
        affects_updated_dt_gt=affects_updated_dt_gt,
        affects_updated_dt_gte=affects_updated_dt_gte,
        affects_updated_dt_lt=affects_updated_dt_lt,
        affects_updated_dt_lte=affects_updated_dt_lte,
        affects_uuid=affects_uuid,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        external_system_id=external_system_id,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_update_stream=ps_update_stream,
        resolution=resolution,
        status=status,
        type=type,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[
        Unset, None, OsidbApiV1TrackersListAffectsAffectedness
    ] = UNSET,
    affects_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_cvss2: Union[Unset, None, str] = UNSET,
    affects_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_cvss3: Union[Unset, None, str] = UNSET,
    affects_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_component: Union[Unset, None, str] = UNSET,
    affects_flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    affects_flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    affects_flaw_cwe_id: Union[Unset, None, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, None, bool] = UNSET,
    affects_flaw_impact: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawImpact
    ] = UNSET,
    affects_flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    affects_flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    affects_flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_source: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawSource
    ] = UNSET,
    affects_flaw_type: Union[
        Unset, None, OsidbApiV1TrackersListAffectsFlawType
    ] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, None, str] = UNSET,
    affects_impact: Union[Unset, None, OsidbApiV1TrackersListAffectsImpact] = UNSET,
    affects_ps_component: Union[Unset, None, str] = UNSET,
    affects_ps_module: Union[Unset, None, str] = UNSET,
    affects_resolution: Union[
        Unset, None, OsidbApiV1TrackersListAffectsResolution
    ] = UNSET,
    affects_type: Union[Unset, None, OsidbApiV1TrackersListAffectsType] = UNSET,
    affects_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, None, str] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    external_system_id: Union[Unset, None, str] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    status: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Optional[OsidbApiV1TrackersListResponse200]:
    """ """

    return sync_detailed(
        client=client,
        affects_affectedness=affects_affectedness,
        affects_created_dt=affects_created_dt,
        affects_created_dt_date=affects_created_dt_date,
        affects_created_dt_date_gte=affects_created_dt_date_gte,
        affects_created_dt_date_lte=affects_created_dt_date_lte,
        affects_created_dt_gt=affects_created_dt_gt,
        affects_created_dt_gte=affects_created_dt_gte,
        affects_created_dt_lt=affects_created_dt_lt,
        affects_created_dt_lte=affects_created_dt_lte,
        affects_cvss2=affects_cvss2,
        affects_cvss2_score=affects_cvss2_score,
        affects_cvss2_score_gt=affects_cvss2_score_gt,
        affects_cvss2_score_gte=affects_cvss2_score_gte,
        affects_cvss2_score_lt=affects_cvss2_score_lt,
        affects_cvss2_score_lte=affects_cvss2_score_lte,
        affects_cvss3=affects_cvss3,
        affects_cvss3_score=affects_cvss3_score,
        affects_cvss3_score_gt=affects_cvss3_score_gt,
        affects_cvss3_score_gte=affects_cvss3_score_gte,
        affects_cvss3_score_lt=affects_cvss3_score_lt,
        affects_cvss3_score_lte=affects_cvss3_score_lte,
        affects_embargoed=affects_embargoed,
        affects_flaw_component=affects_flaw_component,
        affects_flaw_created_dt=affects_flaw_created_dt,
        affects_flaw_created_dt_date=affects_flaw_created_dt_date,
        affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
        affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
        affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
        affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
        affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
        affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
        affects_flaw_cve_id=affects_flaw_cve_id,
        affects_flaw_cvss2=affects_flaw_cvss2,
        affects_flaw_cvss2_score=affects_flaw_cvss2_score,
        affects_flaw_cvss2_score_gt=affects_flaw_cvss2_score_gt,
        affects_flaw_cvss2_score_gte=affects_flaw_cvss2_score_gte,
        affects_flaw_cvss2_score_lt=affects_flaw_cvss2_score_lt,
        affects_flaw_cvss2_score_lte=affects_flaw_cvss2_score_lte,
        affects_flaw_cvss3=affects_flaw_cvss3,
        affects_flaw_cvss3_score=affects_flaw_cvss3_score,
        affects_flaw_cvss3_score_gt=affects_flaw_cvss3_score_gt,
        affects_flaw_cvss3_score_gte=affects_flaw_cvss3_score_gte,
        affects_flaw_cvss3_score_lt=affects_flaw_cvss3_score_lt,
        affects_flaw_cvss3_score_lte=affects_flaw_cvss3_score_lte,
        affects_flaw_cwe_id=affects_flaw_cwe_id,
        affects_flaw_embargoed=affects_flaw_embargoed,
        affects_flaw_impact=affects_flaw_impact,
        affects_flaw_is_major_incident=affects_flaw_is_major_incident,
        affects_flaw_nvd_cvss2=affects_flaw_nvd_cvss2,
        affects_flaw_nvd_cvss3=affects_flaw_nvd_cvss3,
        affects_flaw_reported_dt=affects_flaw_reported_dt,
        affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
        affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
        affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
        affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
        affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
        affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
        affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
        affects_flaw_source=affects_flaw_source,
        affects_flaw_type=affects_flaw_type,
        affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
        affects_flaw_updated_dt=affects_flaw_updated_dt,
        affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
        affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
        affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
        affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
        affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
        affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
        affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
        affects_flaw_uuid=affects_flaw_uuid,
        affects_impact=affects_impact,
        affects_ps_component=affects_ps_component,
        affects_ps_module=affects_ps_module,
        affects_resolution=affects_resolution,
        affects_type=affects_type,
        affects_updated_dt=affects_updated_dt,
        affects_updated_dt_date=affects_updated_dt_date,
        affects_updated_dt_date_gte=affects_updated_dt_date_gte,
        affects_updated_dt_date_lte=affects_updated_dt_date_lte,
        affects_updated_dt_gt=affects_updated_dt_gt,
        affects_updated_dt_gte=affects_updated_dt_gte,
        affects_updated_dt_lt=affects_updated_dt_lt,
        affects_updated_dt_lte=affects_updated_dt_lte,
        affects_uuid=affects_uuid,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        external_system_id=external_system_id,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_update_stream=ps_update_stream,
        resolution=resolution,
        status=status,
        type=type,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    ).parsed



from enum import Enum


class TaskmanApiV1TaskStatusUpdateResolution(str, Enum):
    CANT_DO = "Can't Do"
    CANNOT_REPRODUCE = "Cannot Reproduce"
    DONE = "Done"
    DONE_ERRATA = "Done-Errata"
    DUPLICATE = "Duplicate"
    MIRRORORPHAN = "MirrorOrphan"
    NOT_A_BUG = "Not a Bug"
    OBSOLETE = "Obsolete"
    TEST_PENDING = "Test Pending"
    WONT_DO = "Won't Do"

    def __str__(self) -> str:
        return str(self.value)
